@@ -23,8 +23,6 @@
 #define _GTKHTML_H_
 
 #include <sys/types.h>
-#include <gtk/gtklayout.h>
-#include <gtk/gtkbindings.h>
 
 #include "gtkhtml-types.h"
 #include "gtkhtml-enums.h"
@@ -131,7 +129,7 @@ struct _GtkHTMLEditorAPI
 };
 
 /* Creation.  */
-GtkType                    gtk_html_get_type                      (void);
+GType                    gtk_html_get_type                      (void);
 void                       gtk_html_construct                     (GtkHTML                   *html);
 GtkWidget                 *gtk_html_new                           (void);
 void                       gtk_html_set_editor_api                (GtkHTML                   *html,
@@ -156,11 +154,6 @@ void                       gtk_html_select_line                   (GtkHTML
 void                       gtk_html_select_paragraph              (GtkHTML                   *html);
 void                       gtk_html_select_paragraph_extended     (GtkHTML                   *html);
 void                       gtk_html_select_all                    (GtkHTML                   *html);
-int                        gtk_html_request_paste                 (GtkHTML                   *html,
-								   GdkAtom                    selection,
-								   gint                       type,
-								   gint32                     time,
-								   gboolean                   as_cite);
 /* Loading.  */
 GtkHTMLStream             *gtk_html_begin                         (GtkHTML                   *html);
 GtkHTMLStream             *gtk_html_begin_full                    (GtkHTML                   *html,
@@ -210,6 +203,9 @@ void                       gtk_html_set_caret_mode                (GtkHTML
 								   gboolean                   caret_mode);
 gboolean                   gtk_html_get_caret_mode                (const GtkHTML             *html);
 
+void			   gtk_html_set_caret_first_focus_anchor  (GtkHTML		     *html,
+								   const char                *name);
+
 /* Animated Images */
 void                       gtk_html_set_animate                   (GtkHTML                   *html,
 								   gboolean                   animate);
